#coding:utf-8
import time

from lib.protocol.report.GPSReport_protocol import GPSReport_protocol
from lib.protocol.report.ProtocolBase import ProtocolBase
from lib.protocol.appendix.EventClass import EventClass

'''
终端上事件数据包
'''

class EventReport_protocol(ProtocolBase):

    def __init__(self,msgCount = 1,WATER_CODE = 26,DEV_ID = "M121501010001",locationType=1,eventType="0036"):
        super().__init__()
        self.msgCount = msgCount                             #数据包个数

        self.WATER_CODE = int(WATER_CODE);                   #消息流水号
        self.DEV_ID = DEV_ID                                 #设备id

        self.locationType = int(locationType)                # 定位类型
        #self.GPSPkg = GPSpkg & BaseStationPkg  # GPS包或者基站包
        self.GPSPkg = "1401091213260265b86206ed8c70026103280000752f03030405af017102610bb800003200000186a0001ed2a25e16fe3a"
        self.BaseStationPkg = "1401140a0c050207e407e607e807ea07ec4eea4eec4eee4ef04efc4efe4f004f024f040024025e07d00007a125000927c60000ea610100"
        self.eventType = eventType                           #事件类别

    def setLatitude(self,data):
        self.latitude = data
    def setLongtitude(self,data):
        self.longitude = data
    def setEventType(self,data):
        self.eventType = data
    def setLocationType(self,data):
        self.locationType = data
    def setGPSPkg(self,data):
        self.GPSPkg = data
    def setBaseStationPkg(self,data):
        self.BaseStationPkg = data



    #####################################################
    #               生成事件信息消息
    #####################################################
    def generateEventMsg(self):
        self.getProtocalHeader()
        info = ""
        #消息头
        HEADER = "4040"
        #消息流水号
        WATER_CODE = self.getWaterCode(self.WATER_CODE)
        #设备id
        DEV_ID = self.devid2hexString(self.DEV_ID)
        # 功能id(GPS功能id)
        FUN_ID = "0021"
        #数据段
        data = ""
        for i in range(0,self.msgCount):
            data += self.generateEventPkg(self.msgCount,self.generateEventData())
        # 消息长度
        LENGTH = self.getMsgLength(int(len(WATER_CODE + DEV_ID + FUN_ID + data)/2))

        info += HEADER
        info += LENGTH
        info += WATER_CODE
        info += DEV_ID
        info += FUN_ID
        info += data
        # 校验字段
        CHECK_CODE = self.getCheckCode(info)
        info += CHECK_CODE
        return info

    #####################################################
    #               创建GPS数据包，包含包个数
    #               data:传入GPS数据包的多条数据段
    #####################################################
    def generateEventPkg(self,pkgNum,data):
        pkgNumHex = self.int2hexString(int(pkgNum))
        pkg = pkgNumHex + data
        return pkg


    #####################################################
    #               创建事件信息数据段
    #####################################################
    def generateEventData(self):
        data = ""
        locationType = self.int2hexString(self.locationType)               #定位类型
        locationData = ""                                                  #GPS包或基站包
        if self.locationType == 1:
            locationData = self.GPSPkg
        elif self.locationType == 2:
            locationData = self.BaseStationPkg
        eventType = self.eventType
        extraInfo = self.getExtraData(eventType)                                      #附带信息
        extraInfoLen = self.int2hexStringByBytes(int((len(extraInfo) / 2)),2)                #附带信息长度

        data = locationType + locationData + eventType + extraInfoLen + extraInfo
        return data

    #####################################################
    #               获取附带信息
    #####################################################
    def getExtraData(self,eventType):
        if eventType == "0001":                                          #终端插入报警
            return EventClass().terminalInsertionAlarmExtraInfo()
        elif eventType == "0002":                                        #终端拔出报警
            return EventClass().terminalPulloutAlarmExtraInfo()
        elif eventType == "0003":                                        #汽车电瓶低电压报警
            return ""
        elif eventType == "0004":                                        #终端主电断电报警
            return ""
        elif eventType == "0005":                                        #GPS模块故障报
            return ""
        elif eventType == "0006":                                        #GPS天线开路报警
            return ""
        elif eventType == "0007":                                        #GPS天线短路报警
            return ""
        elif eventType == "0008":                                        #GPS定位时间过长报警
            return ""
        elif eventType == "0009":                                        #FLASH故障报警
            return ""
        elif eventType == "000A":                                        #CAN模块故障报警
            return ""
        elif eventType == "000B":                                        #3D传感器故障报警
            return ""
        elif eventType == "000C":                                        #RTC模块故障报警
            return ""
        elif eventType == "000D":                                        #TF卡故障报警
            return ""
        elif eventType == "000E":                                        #刷卡器故障报警
            return ""
        elif eventType == "000F":                                        #汽车预点火上报
            return EventClass().preFiringExtraInfo()
        elif eventType == "0010":                                        #汽车点火上报
            eventObj = EventClass()
            eventObj.setGPSpkg(self.GPSPkg)
            return eventObj.fireExtraInfo()
        elif eventType == "0011":                                        #汽车熄火上报
            eventObj = EventClass()
            eventObj.setGPSpkg(self.GPSPkg)
            return eventObj.misFireExtraInfo()
        elif eventType == "0012":                                        #汽车设防上报
            return EventClass().setUpDefencesExtraInfo()
        elif eventType == "0013":                                        #汽车撤防上报
            return EventClass().setDownDefencesExtraInfo()
        elif eventType == "0014":                                        #锁车未成功提醒
            return EventClass().lockCarFaillExtraInfo()
        elif eventType == "0015":                                        #超时未设防提醒
            return EventClass().noDefencesWithTimeoutExtraInfo()
        elif eventType == "0016":                                        #设防玻璃未关提醒
            return EventClass().defencesGlassNoCloseExtraInfo()
        elif eventType == "0017":                                        #设防非法开门报警
            return EventClass().defencesIllegalCloseDoorExtraInfo()
        elif eventType == "0036":                                        #低档高速报警
            return EventClass().lowGearHighSpeedAlarm()
        elif eventType == "0037":                                        #高档低速报警
            return EventClass().highGearLowSpeedAlarm()
        elif eventType == "004A":                                        #剩余油量异常告警
            return EventClass().surplusOilAlarm()

